<?php

/**
 * tables par lignes avec tri des colonnes.
 *
 * Syntaxe {up table-sort|paging=0 ou 1|pageLength=20 (utilisé si paging=1)}contenu table{/up table-sort}
 *
 * IMPERATIF : Les titres des colonnes doivent être dans une balise thead.
 *
 * @author    pmleconte
 * @version   1.0 - 02/2019
 * @license   <a href="http://www.gnu.org/licenses/gpl-3.0.html" target="_blank">GNU/GPLv3</a>
 * @credit    <a href="https://www.datatables.net" target="_blank">DataTables.net</a>
 * */
defined('_JEXEC') or die;

class table_sort extends upAction {

    function init() {
        // charger les ressources communes à toutes les instances de l'action
        $this->load_file('datatables.min.js');
		$this->load_file('datatables.min.css');
        return true;
    }

    function run() {

        // cette action a obligatoirement du contenu
        if (!$this->ctrl_content_exists()) {
            return false;
        }

        // lien vers la page de demo (vide=page sur le site de UP)
        $this->set_demopage();

        // ===== valeur paramétres par défaut (sauf JS)
        $options_def = array(
            __class__ => '', // rien
            'id' => '',
            'breakpoint' => '720px', // bascule en vue responsive
            'class' => '', // classe(s) pour balise table
            'style' => '', // style inline pour balise table
            'max-height' => '', // max-height pour la table
        );

        // ===== paramétres attendus par le script JS
        $js_options_def = array(
            'paging' => true, // pagination true/false
            'pageLength' => '50', // 50 maxi en cas de pagination
        );
        // on fusionne avec celles dans shortcode
        $options = $this->ctrl_options($options_def, $js_options_def);

        $id = $options['id'];  // l'id qui identifie le bloc action
        // balise table originale et array des attributs
        preg_match('#<table.*>#U', $this->content, $table_opentag_old);
        $table_opentag_old = (!empty($table_opentag_old)) ? $table_opentag_old[0] : '';
        $table_attr = $this->get_attr_tag($table_opentag_old);

        // si l'user force l'id de la table, on la conserve
        if ($table_attr['id'] > '')
            $id = $table_attr['id'];
        $table_attr['id'] = $id;

        // preparer un array vide pour la div outer
        $outer_attr = $this->get_attr_tag(null);

        // ajout paramétres user
        $this->add_str($table_attr['class'], $options['class']);
        $this->add_str($table_attr['style'], $options['style'], ';');
        $this->add_style($outer_attr['style'], 'max-height', $options['max-height']);
        $this->add_style($outer_attr['style'], 'overflow', 'auto');

        // =========== le code JS
        // les options saisis par l'utilisateur concernant le script JS
        $js_options = $this->only_using_options($js_options_def);
        // -- conversion en chaine Json
        $js_params = $this->json_arrtostr($js_options, 1);

        $code = '$("#' . $id . '").dataTable(';
        $code .= $js_params;
        $code .= ');';
        $this->load_jquery_code($code);

        // === mise à jour attributs de la table dans $content
        $table_opentag_new = $this->set_attr_tag('table', $table_attr);
        $this->content = str_replace($table_opentag_old, $table_opentag_new, $this->content);

        // ==== code pour retour
        $out = '';
        $out .= $this->set_attr_tag('div', $outer_attr);
        $out .= $this->content;
        $out .= '</div>';

        return $out;
    }

// run
}

// class
